@@ -12,7 +12,8 @@ from aasm.intermediate.argument import (AgentParam, Connection, ConnectionList,
                                         SendMessageParam)
 from aasm.intermediate.behaviour import MessageReceivedBehaviour
 from aasm.intermediate.block import Block
-from aasm.intermediate.declaration import Declaration
+from aasm.intermediate.declaration import (ConnectionDeclaration, Declaration,
+                                           FloatDeclaration)
 from aasm.intermediate.instruction import (Add, AddElement, Clear, Comparaison,
                                            Cos, Divide, ExpDist,
                                            ExponentiationOperation, IfEqual,
@@ -422,6 +423,9 @@ class PythonSpadeCode(PythonCode):
                 prop = arg.expr.split('.')[1]
                 return f'send[\"{prop}\"]'
             
+            case Connection():
+                return f'\"{arg.expr}\"'
+            
             case _:
                 return arg.expr
         
@@ -437,12 +441,18 @@ class PythonSpadeCode(PythonCode):
                     self.add_block(statement)
                     self.indent_left()
 
-                case Declaration():
+                case FloatDeclaration():
                     self.add_line('')
-                    self.add_line("# declaration")
+                    self.add_line("# float declaration")
                     value = f'self.agent.limit_number({self.parse_arg(statement.value)})'
                     self.add_line(f'{statement.name} = {value}')
                 
+                case ConnectionDeclaration():
+                    self.add_line('')
+                    self.add_line("# connection declaration")
+                    value = f'{self.parse_arg(statement.value)}'
+                    self.add_line(f'{statement.name} = {value}')
+                
                 case Subset():
                     self.add_line('')
                     self.add_line("# subset")
@@ -658,15 +668,15 @@ class PythonSpadeCode(PythonCode):
                     list_ = self.parse_arg(statement.list_)
                     element = self.parse_arg(statement.element)
                     match statement:
-                        case AddElement() if isinstance(statement.list_.type_in_op, FloatList):
-                            self.add_line('')
-                            self.add_line("# add element")
-                            self.add_line(f'{list_}.append({element})')
-
-                        case AddElement():
+                        case AddElement() if isinstance(statement.element.type_in_op, MessageList):
                             self.add_line('')
                             self.add_line("# add element")
                             self.add_line(f'if {element} not in {list_}: {list_}.append({element})')
+                                                
+                        case AddElement():
+                            self.add_line('')
+                            self.add_line("# add element")
+                            self.add_line(f'{list_}.append({element})')
 
                         case RemoveElement():
                             self.add_line('')
@@ -737,18 +747,18 @@ class PythonSpadeCode(PythonCode):
                     
                 case TrigonometryOperation():
                     dst = self.parse_arg(statement.dst)
-                    angle_rad = f'self.agent.limit_number({self.parse_arg(statement.rad_angle)})'
+                    degree = f'self.agent.limit_number({self.parse_arg(statement.degree)})'
                     
                     match statement:
                         case Sin():
                             self.add_line('')
                             self.add_line("# sin")
-                            self.add_line(f'{dst} = self.agent.limit_number(numpy.sin({angle_rad}))')
+                            self.add_line(f'{dst} = self.agent.limit_number(numpy.sin(numpy.deg2rad({degree})))')
                             
                         case Cos():
                             self.add_line('')
                             self.add_line("# cos")
-                            self.add_line(f'{dst} = self.agent.limit_number(numpy.cos({angle_rad}))')
+                            self.add_line(f'{dst} = self.agent.limit_number(numpy.cos(numpy.deg2rad({degree})))')
                             
                         case _:
                             raise Exception(f'Unknown trigonometry operation statement: {statement.print()}')
