@@ -4,6 +4,7 @@ from copy import deepcopy
 from pprint import pprint
 from typing import TYPE_CHECKING, Dict, Generator, List, NoReturn, Tuple
 
+from aasm.preprocessor.preprocessor import Preprocessor
 from aasm.utils.exception import PanicException
 
 if TYPE_CHECKING:
@@ -24,7 +25,8 @@ class ParsedData:
 class State:
     def __init__(self, lines: List[str], debug: bool):
         self.debug: bool = debug
-        self.lines: List[str] = lines
+        self.preprocessor = Preprocessor(lines)
+        self.lines: List[str] = self.preprocessor.run()
         self.line_num: int = 0
         self.in_agent: bool = False
         self.in_message: bool = False
@@ -34,50 +36,50 @@ class State:
         self.agents: Dict[str, Agent] = {}
         self.messages: Dict[Tuple[str, str], Message] = {}
         self.graph: Graph | None = None
-        
+
     @property
     def last_agent(self) -> Agent:
         return self.agents[list(self.agents.keys())[-1]]
-    
+
     @property
     def last_behaviour(self) -> Behaviour:
         return self.last_agent.last_behaviour
-    
+
     @property
     def last_action(self) -> Action:
         return self.last_agent.last_behaviour.last_action
-    
+
     @property
     def last_message(self) -> Message:
         return self.messages[list(self.messages.keys())[-1]]
-    
+
     @property
     def last_graph(self) -> Graph:
         if self.graph is None:
             raise Exception('Graph is not defined')
         return self.graph
-    
+
     def add_agent(self, agent: Agent) -> None:
         self.agents[agent.name] = agent
-        
+
     def add_message(self, message: Message) -> None:
         self.messages[(message.type, message.performative)] = message
 
     def add_graph(self, graph: Graph) -> None:
         self.graph = graph
-        
+
     def agent_exists(self, name: str) -> bool:
         return name in self.agents
-    
+
     def message_exists(self, msg_type: str, msg_performative: str) -> bool:
         return (msg_type, msg_performative) in self.messages
 
     def graph_exists(self) -> bool:
         return self.graph is not None
-    
+
     def get_message_instance(self, msg_type: str, msg_performative: str) -> Message:
         return deepcopy(self.messages[(msg_type, msg_performative)])
-            
+
     def tokens_from_lines(self) -> Generator[list[str], None, None]:
         for line in self.lines:
             self.line_num += 1
@@ -86,7 +88,7 @@ class State:
             if tokens:
                 tokens[0] = tokens[0].upper()
                 yield tokens
-                
+
     def print(self) -> None:
         if self.messages:
             print('- Messages:')
@@ -101,7 +103,7 @@ class State:
         if self.graph:
             print('- Graph:')
             self.graph.print()
-    
+
     def verify_end_state(self) -> None:
         if self.in_agent:
             self.panic('Missing EAGENT')
@@ -109,7 +111,7 @@ class State:
             self.panic('Missing EMESSAGE')
         elif self.in_graph:
             self.panic('Missing EGRAPH')
-            
+
     def get_parsed_data(self) -> ParsedData:
         self.verify_end_state()
         if self.debug:
@@ -121,7 +123,8 @@ class State:
         if self.debug:
             pprint(self.__dict__)
             self.print()
-        place = f'Error in line {self.line_num}: {self.lines[self.line_num - 1].strip()}'
+        err_line = self.preprocessor.get_original_line_number(self.line_num)
+        place = f'Error in line {err_line}: {self.lines[self.line_num - 1].strip()}'
         raise PanicException(place, reason, suggestion)
 
     def require(self, expr: bool, msg_on_error: str, suggestion_on_error: str = '') -> None:
